#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-
# This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; version 2 of the License.
# This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
import sys
import getopt
from MainGui import *
from ServerHandler import *
from Watcher import *

""" Programa presentMe, presentaciones en ambiente multicast
:author: Rodrigo Amaro 
:version: 0.1
@license: U{http://creativecommons.org/licenses/by-nc-nd/3.0/us/}
"""
class Controller:
    """Controlador de las clases que componen el programa
    
    @note: En etapa de desarrollo
    @ivar pdf_file: clase que controla archivos pdf
    @type pdf_file: L{PdfConvert}
    @ivar server_handler: Instancia del controlador de socketss multicast
    @type server_handler: L{ServerHandler}
    @ivar self.mainWindows: Instancia del controlador de socketss multicast
    @type self.mainWindows: L{MainGui}
    """

    def __init__(self):
        """Constructor de la clase 
        @param self: 2
       
        """

        self.port = 1600
        self.host = "224.168.2.9"
        self.pdf_file = None
        hasAudio=False
        self.isServer = False

        try:
            opts, args = getopt.getopt(sys.argv[1:], "hf:p:m:a", ["help","file-pdf=","port=","multicast-host=","audio-on"])
        except getopt.error:
            self.help()
            sys.exit(2)
        for o, a in opts:
            if o in ("-h", "--help"):
                self.help()
                sys.exit()
            elif o in ("-f", "--file-pdf"):
                self.isServer = True
                from PdfConvert import PdfConvert
                self.pdf_file = PdfConvert(a,530,400)
            elif o in ("-p", "--port"):
                self.port = int(a)
            elif o in ("-m", "--multicast-host"):
                self.host = a
            elif o in ("-a", "--audio-on"):
                hasAudio = True
            else:
                self.help()
                sys.exit()

        self.server_handler = ServerHandler(mcast_addr=self.host,mcastPort=self.port)
        if hasAudio:
            if self.isServer:
                from AudioServer import AudioServer
                audio = AudioServer(self.host,self.port+2)
            else:
                from AudioClient import AudioClient
                audio = AudioClient(self.host,self.port+2)
            audio.go()
        self.mainWindows = MainGui(self)
        self.server_handler.start_text_listener(self.mainWindows.chat_area)
        self.server_handler.start_image_listener(self.mainWindows.image_area)
  
        self.init_gui()
    """Inicio de a interfaz grfica"""
    def init_gui(self):
        gtk.gdk.threads_init()
        gtk.main()
    """Metodo auxiliar para mostrar la ayuda"""
    def help(self):
        print '''
Usage: python presentMe.py [OPTIONS]

If you put a pdf file in the line comand , the program automatically turns on MulticastServer, else, this is only a MulticastClient

Options:
 -m,  --multicast-host <ip>	The multicast address group  
 -p,  --port <port>		The multicast port group
 -f,  --file-pdf <path> 	The file to serve
 -a,  --audio-on		Enable the audio server
 -h,  --help 			This help!

	'''

def main():
    Watcher()
    Controller()
    pass
    

if __name__ == "__main__":
    main()
